==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/a1/a14f2a144a75c169de1c1c8b51d12761.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Event/LeadListFilteringEvent.php */
class __TwigTemplate_f15b160e7f44d4775ab824e1b2b22587 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Event;

use Doctrine\\ORM\\EntityManager;
use Doctrine\\ORM\\EntityManagerInterface;
use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\LeadBundle\\Segment\\Query\\QueryBuilder;

/**
 * Please refer to LeadListRepository.php, inside getListFilterExprCombined method, for examples.
 */
class LeadListFilteringEvent extends CommonEvent
{
    protected bool \$isFilteringDone;

    protected string \$subQuery;

    private string \$leadsTableAlias;

    /**
     * @param array        \$details
     * @param int          \$leadId
     * @param string       \$alias
     * @param string       \$func
     * @param QueryBuilder \$queryBuilder
     */
    public function __construct(
        protected \$details,
        protected \$leadId,
        protected \$alias,
        protected \$func,
        protected \$queryBuilder,
        EntityManager \$entityManager
    ) {
        \$this->em              = \$entityManager;
        \$this->isFilteringDone = false;
        \$this->subQuery        = '';
        \$this->leadsTableAlias = \$queryBuilder->getTableAlias(MAUTIC_TABLE_PREFIX.'leads');
    }

    /**
     * @return array
     */
    public function getDetails()
    {
        return \$this->details;
    }

    /**
     * @return int
     */
    public function getLeadId()
    {
        return \$this->leadId;
    }

    /**
     * @return string
     */
    public function getAlias()
    {
        return \$this->alias;
    }

    /**
     * @return string
     */
    public function getFunc()
    {
        return \$this->func;
    }

    /**
     * @return EntityManagerInterface
     */
    public function getEntityManager()
    {
        return \$this->em;
    }

    /**
     * @return QueryBuilder
     */
    public function getQueryBuilder()
    {
        return \$this->queryBuilder;
    }

    /**
     * @param bool \$status
     */
    public function setFilteringStatus(\$status): void
    {
        \$this->isFilteringDone = \$status;
    }

    /**
     * @param string \$query
     */
    public function setSubQuery(\$query): void
    {
        \$this->subQuery = \$query;

        \$this->setFilteringStatus(true);
    }

    public function isFilteringDone(): bool
    {
        return \$this->isFilteringDone;
    }

    public function getSubQuery(): string
    {
        return \$this->subQuery;
    }

    /**
     * @param array \$details
     */
    public function setDetails(\$details): void
    {
        \$this->details = \$details;
    }

    public function getLeadsTableAlias(): string
    {
        return \$this->leadsTableAlias;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Event/LeadListFilteringEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Event/LeadListFilteringEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Event/LeadListFilteringEvent.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/a1/a14f2a144a75c169de1c1c8b51d12761.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Event/LeadListFilteringEvent.php */
class __TwigTemplate_f15b160e7f44d4775ab824e1b2b22587 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Event;

use Doctrine\\ORM\\EntityManager;
use Doctrine\\ORM\\EntityManagerInterface;
use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\LeadBundle\\Segment\\Query\\QueryBuilder;

/**
 * Please refer to LeadListRepository.php, inside getListFilterExprCombined method, for examples.
 */
class LeadListFilteringEvent extends CommonEvent
{
    protected bool \$isFilteringDone;

    protected string \$subQuery;

    private string \$leadsTableAlias;

    /**
     * @param array        \$details
     * @param int          \$leadId
     * @param string       \$alias
     * @param string       \$func
     * @param QueryBuilder \$queryBuilder
     */
    public function __construct(
        protected \$details,
        protected \$leadId,
        protected \$alias,
        protected \$func,
        protected \$queryBuilder,
        EntityManager \$entityManager
    ) {
        \$this->em              = \$entityManager;
        \$this->isFilteringDone = false;
        \$this->subQuery        = '';
        \$this->leadsTableAlias = \$queryBuilder->getTableAlias(MAUTIC_TABLE_PREFIX.'leads');
    }

    /**
     * @return array
     */
    public function getDetails()
    {
        return \$this->details;
    }

    /**
     * @return int
     */
    public function getLeadId()
    {
        return \$this->leadId;
    }

    /**
     * @return string
     */
    public function getAlias()
    {
        return \$this->alias;
    }

    /**
     * @return string
     */
    public function getFunc()
    {
        return \$this->func;
    }

    /**
     * @return EntityManagerInterface
     */
    public function getEntityManager()
    {
        return \$this->em;
    }

    /**
     * @return QueryBuilder
     */
    public function getQueryBuilder()
    {
        return \$this->queryBuilder;
    }

    /**
     * @param bool \$status
     */
    public function setFilteringStatus(\$status): void
    {
        \$this->isFilteringDone = \$status;
    }

    /**
     * @param string \$query
     */
    public function setSubQuery(\$query): void
    {
        \$this->subQuery = \$query;

        \$this->setFilteringStatus(true);
    }

    public function isFilteringDone(): bool
    {
        return \$this->isFilteringDone;
    }

    public function getSubQuery(): string
    {
        return \$this->subQuery;
    }

    /**
     * @param array \$details
     */
    public function setDetails(\$details): void
    {
        \$this->details = \$details;
    }

    public function getLeadsTableAlias(): string
    {
        return \$this->leadsTableAlias;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Event/LeadListFilteringEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Event/LeadListFilteringEvent.php", "/var/www/html/production-demo/app/bundles/LeadBundle/Event/LeadListFilteringEvent.php");
    }
}
